@@ -94,16 +94,19 @@ CMD_DECL(dimension_split)
 CMD_DECL(extract)
 CMD_DECL(fill)
 CMD_DECL(from_csv)
+CMD_DECL(from_datraw)
 CMD_DECL(from_dcmtk)
 CMD_DECL(from_exr)
 CMD_DECL(from_ffmpeg)
 CMD_DECL(from_gdal)
+CMD_DECL(from_jpeg)
 CMD_DECL(from_magick)
 CMD_DECL(from_mat)
 CMD_DECL(from_netpbm)
 CMD_DECL(from_pcd)
 CMD_DECL(from_pfs)
 CMD_DECL(from_ply)
+CMD_DECL(from_pvm)
 CMD_DECL(from_rat)
 CMD_DECL(from_raw)
 CMD_DECL(from_sndfile)
@@ -119,14 +122,17 @@ CMD_DECL(stream_merge)
 CMD_DECL(stream_split)
 CMD_DECL(tag)
 CMD_DECL(to_csv)
+CMD_DECL(to_datraw)
 CMD_DECL(to_exr)
 CMD_DECL(to_gdal)
+CMD_DECL(to_jpeg)
 CMD_DECL(to_magick)
 CMD_DECL(to_mat)
 CMD_DECL(to_netpbm)
 CMD_DECL(to_pcd)
 CMD_DECL(to_pfs)
 CMD_DECL(to_ply)
+CMD_DECL(to_pvm)
 CMD_DECL(to_rat)
 CMD_DECL(to_raw)
 CMD_DECL(to_sndfile)
@@ -156,16 +162,19 @@ static cmd_t cmds[] =
     CMD("extract",           array,      extract,           true,          BUILTIN),
     CMD("fill",              array,      fill,              true,          BUILTIN),
     CMD("from-csv",          conversion, from_csv,          WITH_CSV,      "conv-csv"),
+    CMD("from-datraw",       conversion, from_datraw,       WITH_DATRAW,   "conv-datraw"),
     CMD("from-dcmtk",        conversion, from_dcmtk,        WITH_DCMTK,    "conv-dcmtk"),
     CMD("from-exr",          conversion, from_exr,          WITH_EXR,      "conv-exr"),
     CMD("from-ffmpeg",       conversion, from_ffmpeg,       WITH_FFMPEG,   "conv-ffmpeg"),
     CMD("from-gdal",         conversion, from_gdal,         WITH_GDAL,     "conv-gdal"),
+    CMD("from-jpeg",         conversion, from_jpeg,         WITH_JPEG,     "conv-jpeg"),
     CMD("from-magick",       conversion, from_magick,       WITH_MAGICK,   "conv-magick"),
     CMD("from-mat",          conversion, from_mat,          WITH_MAT,      "conv-mat"),
     CMD("from-netpbm",       conversion, from_netpbm,       WITH_NETPBM,   "conv-netpbm"),
     CMD("from-pcd",          conversion, from_pcd,          WITH_PCD,      "conv-pcd"),
     CMD("from-pfs",          conversion, from_pfs,          WITH_PFS,      "conv-pfs"),
     CMD("from-ply",          conversion, from_ply,          WITH_PLY,      "conv-ply"),
+    CMD("from-pvm",          conversion, from_pvm,          WITH_PVM,      "conv-pvm"),
     CMD("from-rat",          conversion, from_rat,          WITH_RAT,      "conv-rat"),
     CMD("from-raw",          conversion, from_raw,          WITH_RAW,      "conv-raw"),
     CMD("from-sndfile",      conversion, from_sndfile,      WITH_SNDFILE,  "conv-sndfile"),
@@ -181,14 +190,17 @@ static cmd_t cmds[] =
     CMD("stream-split",      stream,     stream_split,      true,          BUILTIN),
     CMD("tag",               array,      tag,               true,          BUILTIN),
     CMD("to-csv",            conversion, to_csv,            WITH_CSV,      "conv-csv"),
+    CMD("to-datraw",         conversion, to_datraw,         WITH_DATRAW,   "conv-datraw"),
     CMD("to-exr",            conversion, to_exr,            WITH_EXR,      "conv-exr"),
     CMD("to-gdal",           conversion, to_gdal,           WITH_GDAL,     "conv-gdal"),
+    CMD("to-jpeg",           conversion, to_jpeg,           WITH_JPEG,     "conv-jpeg"),
     CMD("to-magick",         conversion, to_magick,         WITH_MAGICK,   "conv-magick"),
     CMD("to-mat",            conversion, to_mat,            WITH_MAT,      "conv-mat"),
     CMD("to-netpbm",         conversion, to_netpbm,         WITH_NETPBM,   "conv-netpbm"),
     CMD("to-pcd",            conversion, to_pcd,            WITH_PCD,      "conv-pcd"),
     CMD("to-pfs",            conversion, to_pfs,            WITH_PFS,      "conv-pfs"),
     CMD("to-ply",            conversion, to_ply,            WITH_PLY,      "conv-ply"),
+    CMD("to-pvm",            conversion, to_pvm,            WITH_PVM,      "conv-pvm"),
     CMD("to-rat",            conversion, to_rat,            WITH_RAT,      "conv-rat"),
     CMD("to-raw",            conversion, to_raw,            WITH_RAW,      "conv-raw"),
     CMD("to-sndfile",        conversion, to_sndfile,        WITH_SNDFILE,  "conv-sndfile"),
