@@ -558,6 +558,13 @@ GUI::GUI()
         file_import_csv_action->setEnabled(false);
     }
     file_import_menu->addAction(file_import_csv_action);
+    QAction *file_import_datraw_action = new QAction(tr("Volume data in .dat/.raw format..."), this);
+    connect(file_import_datraw_action, SIGNAL(triggered()), this, SLOT(file_import_datraw()));
+    if (!cmd_is_available(cmd_find("from-datraw")))
+    {
+        file_import_datraw_action->setEnabled(false);
+    }
+    file_import_menu->addAction(file_import_datraw_action);
     QAction *file_import_dcmtk_action = new QAction(tr("DICOM files (via DCMTK)..."), this);
     connect(file_import_dcmtk_action, SIGNAL(triggered()), this, SLOT(file_import_dcmtk()));
     if (!cmd_is_available(cmd_find("from-dcmtk")))
@@ -586,6 +593,13 @@ GUI::GUI()
         file_import_gdal_action->setEnabled(false);
     }
     file_import_menu->addAction(file_import_gdal_action);
+    QAction *file_import_jpeg_action = new QAction(tr("JPEG images (via libjpeg)..."), this);
+    connect(file_import_jpeg_action, SIGNAL(triggered()), this, SLOT(file_import_jpeg()));
+    if (!cmd_is_available(cmd_find("from-jpeg")))
+    {
+        file_import_jpeg_action->setEnabled(false);
+    }
+    file_import_menu->addAction(file_import_jpeg_action);
     QAction *file_import_magick_action = new QAction(tr("Image data (via ImageMagick)..."), this);
     connect(file_import_magick_action, SIGNAL(triggered()), this, SLOT(file_import_magick()));
     if (!cmd_is_available(cmd_find("from-magick")))
@@ -621,6 +635,13 @@ GUI::GUI()
         file_import_ply_action->setEnabled(false);
     }
     file_import_menu->addAction(file_import_ply_action);
+    QAction *file_import_pvm_action = new QAction(tr("PVM volume data..."), this);
+    connect(file_import_pvm_action, SIGNAL(triggered()), this, SLOT(file_import_pvm()));
+    if (!cmd_is_available(cmd_find("from-pvm")))
+    {
+        file_import_pvm_action->setEnabled(false);
+    }
+    file_import_menu->addAction(file_import_pvm_action);
     QAction *file_import_rat_action = new QAction(tr("RAT RadarTools data..."), this);
     connect(file_import_rat_action, SIGNAL(triggered()), this, SLOT(file_import_rat()));
     if (!cmd_is_available(cmd_find("from-rat")))
@@ -657,6 +678,13 @@ GUI::GUI()
         file_export_csv_action->setEnabled(false);
     }
     file_export_menu->addAction(file_export_csv_action);
+    QAction *file_export_datraw_action = new QAction(tr("Volume data in .dat/.raw format..."), this);
+    connect(file_export_datraw_action, SIGNAL(triggered()), this, SLOT(file_export_datraw()));
+    if (!cmd_is_available(cmd_find("to-datraw")))
+    {
+        file_export_datraw_action->setEnabled(false);
+    }
+    file_export_menu->addAction(file_export_datraw_action);
     QAction *file_export_exr_action = new QAction(tr("EXR HDR images (via EXR)..."), this);
     connect(file_export_exr_action, SIGNAL(triggered()), this, SLOT(file_export_exr()));
     if (!cmd_is_available(cmd_find("to-exr")))
@@ -671,6 +699,13 @@ GUI::GUI()
         file_export_gdal_action->setEnabled(false);
     }
     file_export_menu->addAction(file_export_gdal_action);
+    QAction *file_export_jpeg_action = new QAction(tr("JPEG images (via libjpeg)..."), this);
+    connect(file_export_jpeg_action, SIGNAL(triggered()), this, SLOT(file_export_jpeg()));
+    if (!cmd_is_available(cmd_find("to-jpeg")))
+    {
+        file_export_jpeg_action->setEnabled(false);
+    }
+    file_export_menu->addAction(file_export_jpeg_action);
     QAction *file_export_magick_action = new QAction(tr("Image data (via ImageMagick)..."), this);
     connect(file_export_magick_action, SIGNAL(triggered()), this, SLOT(file_export_magick()));
     if (!cmd_is_available(cmd_find("to-magick")))
@@ -706,6 +741,13 @@ GUI::GUI()
         file_export_ply_action->setEnabled(false);
     }
     file_export_menu->addAction(file_export_ply_action);
+    QAction *file_export_pvm_action = new QAction(tr("PVM volume data..."), this);
+    connect(file_export_pvm_action, SIGNAL(triggered()), this, SLOT(file_export_pvm()));
+    if (!cmd_is_available(cmd_find("to-pvm")))
+    {
+        file_export_pvm_action->setEnabled(false);
+    }
+    file_export_menu->addAction(file_export_pvm_action);
     QAction *file_export_rat_action = new QAction(tr("RAT RadarTools data..."), this);
     connect(file_export_rat_action, SIGNAL(triggered()), this, SLOT(file_export_rat()));
     if (!cmd_is_available(cmd_find("to-rat")))
@@ -1443,6 +1485,11 @@ void GUI::file_import_csv()
     import_from("from-csv", std::vector<std::string>(), QStringList("CSV files (*.csv)"));
 }
 
+void GUI::file_import_datraw()
+{
+    import_from("from-datraw", std::vector<std::string>(), QStringList("Volume data files (*.dat)"));
+}
+
 void GUI::file_import_dcmtk()
 {
     import_from("from-dcmtk", std::vector<std::string>(), QStringList("DICOM files (*.dcm)"));
@@ -1463,6 +1510,11 @@ void GUI::file_import_gdal()
     import_from("from-gdal", std::vector<std::string>(), QStringList("TIFF files (*.tif *.tiff)"));
 }
 
+void GUI::file_import_jpeg()
+{
+    import_from("from-jpeg", std::vector<std::string>(), QStringList("JPEG files (*.jpg *.jpeg)"));
+}
+
 void GUI::file_import_magick()
 {
     import_from("from-magick", std::vector<std::string>(), QStringList("Typical image files (*.png *.jpg)"));
@@ -1488,6 +1540,11 @@ void GUI::file_import_ply()
     import_from("from-ply", std::vector<std::string>(), QStringList("PLY files (*.ply)"));
 }
 
+void GUI::file_import_pvm()
+{
+    import_from("from-pvm", std::vector<std::string>(), QStringList("PVM files (*.pvm)"));
+}
+
 void GUI::file_import_rat()
 {
     import_from("from-rat", std::vector<std::string>(), QStringList("RAT RadarTools files (*.rat)"));
@@ -1551,6 +1608,11 @@ void GUI::file_export_csv()
     export_to("to-csv", std::vector<std::string>(), "csv", QStringList("CSV files (*.csv)"));
 }
 
+void GUI::file_export_datraw()
+{
+    export_to("to-datraw", std::vector<std::string>(), "dat", QStringList("Volume data files (*.dat)"));
+}
+
 void GUI::file_export_exr()
 {
     export_to("to-exr", std::vector<std::string>(), "exr", QStringList("EXR files (*.exr)"));
@@ -1561,6 +1623,11 @@ void GUI::file_export_gdal()
     export_to("to-gdal", std::vector<std::string>(), "tif", QStringList("TIFF files (*.tif *.tiff)"));
 }
 
+void GUI::file_export_jpeg()
+{
+    export_to("to-jpeg", std::vector<std::string>(), "jpg", QStringList("JPEG files (*.jpg *.jpeg)"));
+}
+
 void GUI::file_export_magick()
 {
     export_to("to-magick", std::vector<std::string>(), "png", QStringList("Typical image files (*.png *.jpg)"));
@@ -1591,6 +1658,11 @@ void GUI::file_export_ply()
     export_to("to-ply", std::vector<std::string>(), "ply", QStringList("PLY files (*.ply)"));
 }
 
+void GUI::file_export_pvm()
+{
+    export_to("to-pvm", std::vector<std::string>(), "pvm", QStringList("PVM files (*.pvm)"));
+}
+
 void GUI::file_export_raw()
 {
     if (!check_have_file())
